@@ -18,8 +18,7 @@
  *
  **********************************************************************/
 
-#ifndef GEOS_GEOM_PREP_PREPAREDLINESTRING_H
-#define GEOS_GEOM_PREP_PREPAREDLINESTRING_H
+#pragma once
 
 #include <geos/geom/prep/BasicPreparedGeometry.h> // for inheritance
 #include <geos/noding/SegmentString.h>
@@ -60,6 +59,7 @@ public:
     bool intersects(const geom::Geometry* g) const override;
     std::unique_ptr<geom::CoordinateSequence> nearestPoints(const geom::Geometry* g) const override;
     double distance(const geom::Geometry* g) const override;
+    bool isWithinDistance(const geom::Geometry* g, double d) const override;
     operation::distance::IndexedFacetDistance* getIndexedFacetDistance() const;
 
 };
@@ -68,4 +68,3 @@ public:
 } // namespace geos::geom
 } // namespace geos
 
-#endif // GEOS_GEOM_PREP_PREPAREDLINESTRING_H
