@@ -1,36 +1,37 @@
 /**********************************************************************
- * $Id: MonotoneChain.h 2556 2009-06-06 22:22:28Z strk $
  *
  * GEOS - Geometry Engine Open Source
- * http://geos.refractions.net
+ * http://geos.osgeo.org
  *
  * Copyright (C) 2005-2006 Refractions Research Inc.
  * Copyright (C) 2001-2002 Vivid Solutions Inc.
  *
  * This is free software; you can redistribute and/or modify it under
  * the terms of the GNU Lesser General Public Licence as published
- * by the Free Software Foundation. 
+ * by the Free Software Foundation.
  * See the COPYING file for more information.
  *
+ **********************************************************************
+ *
+ * Last port: geomgraph/index/MonotoneChain.java rev. 1.3 (JTS-1.7)
+ *
  **********************************************************************/
 
-#ifndef GEOS_GEOMGRAPH_INDEX_MONOTONECHAIN_H
-#define GEOS_GEOMGRAPH_INDEX_MONOTONECHAIN_H
+#pragma once
 
 
 #include <geos/export.h>
 #include <geos/geomgraph/index/SweepLineEventObj.h> // for inheritance
 #include <geos/geomgraph/index/MonotoneChainEdge.h> // for inline
+#include <geos/geomgraph/index/MonotoneChain.h>
 
 // Forward declarations
 namespace geos {
-	namespace geomgraph {
-		class Edge;
-		namespace index {
-			class SegmentIntersector;
-			//class MonotoneChainEdge; 
-		}
-	}
+namespace geomgraph {
+namespace index {
+class SegmentIntersector;
+}
+}
 }
 
 namespace geos {
@@ -38,40 +39,34 @@ namespace geomgraph { // geos::geomgraph
 namespace index { // geos::geomgraph::index
 
 /**
- * Last port: geomgraph/index/MonotoneChain.java rev. 1.3 (JTS-1.7)
+ * A chain in a MonotoneChainEdge
  */
 class GEOS_DLL MonotoneChain: public SweepLineEventOBJ {
 private:
-	MonotoneChainEdge *mce;
-	int chainIndex;
+    MonotoneChainEdge* mce;
+    std::size_t chainIndex;
+
+    MonotoneChain(const MonotoneChain& other) = delete;
+    MonotoneChain& operator=(const MonotoneChain& rhs) = delete;
 
 public:
 
-	MonotoneChain(MonotoneChainEdge *newMce, int newChainIndex):
-		mce(newMce),
-		chainIndex(newChainIndex)
-	{}
+    MonotoneChain(MonotoneChainEdge* newMce, std::size_t newChainIndex):
+        mce(newMce),
+        chainIndex(newChainIndex)
+    {}
 
-	~MonotoneChain() {}
+    ~MonotoneChain() override {}
 
-	void computeIntersections(MonotoneChain *mc,SegmentIntersector *si) {
-		mce->computeIntersectsForChain(chainIndex,*(mc->mce),mc->chainIndex,*si);
-	}
+    void
+    computeIntersections(MonotoneChain* mc, SegmentIntersector* si)
+    {
+        mce->computeIntersectsForChain(chainIndex, *(mc->mce), mc->chainIndex, *si);
+    }
 };
 
 
-
-
 } // namespace geos.geomgraph.index
 } // namespace geos.geomgraph
 } // namespace geos
 
-#endif
-
-/**********************************************************************
- * $Log$
- * Revision 1.1  2006/03/14 12:55:55  strk
- * Headers split: geomgraphindex.h, nodingSnapround.h
- *
- **********************************************************************/
-
