@@ -1,34 +1,34 @@
 /**********************************************************************
- * $Id: SweepLineEventObj.h 1820 2006-09-06 16:54:23Z mloskot $
  *
  * GEOS - Geometry Engine Open Source
- * http://geos.refractions.net
+ * http://geos.osgeo.org
  *
  * Copyright (C) 2005-2006 Refractions Research Inc.
  * Copyright (C) 2001-2002 Vivid Solutions Inc.
  *
  * This is free software; you can redistribute and/or modify it under
  * the terms of the GNU Lesser General Public Licence as published
- * by the Free Software Foundation. 
+ * by the Free Software Foundation.
  * See the COPYING file for more information.
  *
  **********************************************************************/
 
-#ifndef GEOS_GEOMGRAPH_INDEX_SWEEPLINEEVENTOBJ_H
-#define GEOS_GEOMGRAPH_INDEX_SWEEPLINEEVENTOBJ_H
+#pragma once
 
+#include <geos/export.h>
 
 namespace geos {
 namespace geomgraph { // geos::geomgraph
 namespace index { // geos::geomgraph::index
 
 // This is here so that SweepLineEvent constructor
-// can use it as argument type. 
+// can use it as argument type.
 // Both  SweepLineSegment and MonotoneChain will
 // inherit from it.
-class SweepLineEventOBJ {
+class GEOS_DLL SweepLineEventOBJ {
 public:
-	virtual ~SweepLineEventOBJ(){};
+    virtual
+    ~SweepLineEventOBJ() {}
 };
 
 
@@ -36,12 +36,3 @@ public:
 } // namespace geos.geomgraph
 } // namespace geos
 
-#endif
-
-/**********************************************************************
- * $Log$
- * Revision 1.1  2006/03/14 12:55:56  strk
- * Headers split: geomgraphindex.h, nodingSnapround.h
- *
- **********************************************************************/
-
