@@ -1,21 +1,21 @@
 /**********************************************************************
- * $Id: ItemVisitor.h 1820 2006-09-06 16:54:23Z mloskot $
  *
  * GEOS - Geometry Engine Open Source
- * http://geos.refractions.net
+ * http://geos.osgeo.org
  *
  * Copyright (C) 2006 Refractions Research Inc.
  * Copyright (C) 2001-2002 Vivid Solutions Inc.
  *
  * This is free software; you can redistribute and/or modify it under
  * the terms of the GNU Lesser General Public Licence as published
- * by the Free Software Foundation. 
+ * by the Free Software Foundation.
  * See the COPYING file for more information.
  *
  **********************************************************************/
 
-#ifndef GEOS_INDEX_ITEMVISITOR_H
-#define GEOS_INDEX_ITEMVISITOR_H
+#pragma once
+
+#include <geos/export.h>
 
 namespace geos {
 namespace index {
@@ -25,15 +25,14 @@ namespace index {
  *
  * Last port: index/ItemVisitor.java rev. 1.2 (JTS-1.7)
  */
-class ItemVisitor {
+class GEOS_DLL ItemVisitor {
 public:
-	virtual void visitItem(void *)=0;
+    virtual void visitItem(void*) = 0;
 
-	virtual ~ItemVisitor() {}
+    virtual
+    ~ItemVisitor() {}
 };
 
 } // namespace geos.index
 } // namespace geos
 
-#endif // GEOS_INDEX_ITEMVISITOR_H
-
